Enum clmm_cli::app::PairCommands
source · [−]pub enum PairCommands {
Show 27 variants
AcceptProtocolFeeAuthority {
clmm_config: Pubkey,
},
CollectPartnerFee {
partner: Pubkey,
clmmpool: Pubkey,
},
CollectProtocolFee {
clmmpool: Pubkey,
},
CreatePool {},
PausePool {
clmmpool: Pubkey,
},
UnpausePool {
clmmpool: Pubkey,
},
Info {
pair_key: Pubkey,
},
List {},
InitConfig {},
ConfigInfo {},
CreateFeeTier {},
FeeTierInfo {
fee_tier: Pubkey,
},
CreatePartner {},
PartnerInfo {
partner: Pubkey,
},
CreateTickArray {},
TransferProtocolFeeAuthority {
clmm_config: Pubkey,
new_authority: Pubkey,
},
UpdateConfig {
clmm_config: Pubkey,
new_protocol_fee_rate: Option<u16>,
create_pool_authority: Option<Pubkey>,
claim_authority: Option<Pubkey>,
},
UpdateFeeRate {
new_fee_rate: f64,
clmmpool: Pubkey,
},
UpdatePartner {
partner: Pubkey,
new_fee_rate: Option<u16>,
new_claim_authority: Option<Pubkey>,
start_time: Option<u64>,
end_time: Option<u64>,
},
Swap {
clmmpool: Pubkey,
amount: f64,
a_to_b: Option<bool>,
by_amount_in: Option<bool>,
price_limit_tick: Option<i32>,
},
SwapWithPartner {
clmmpool: Pubkey,
partner: Pubkey,
amount: f64,
a_to_b: Option<bool>,
by_amount_in: Option<bool>,
price_limit_tick: Option<i32>,
},
InitRewarder {
clmmpool: Pubkey,
rewarder_token_mint: Pubkey,
rewarder_index: u8,
mint_wrapper: Pubkey,
minter: Pubkey,
},
UpdateRewarderEmission {
clmmpool: Pubkey,
rewarder_index: u8,
emissions_per_day: f64,
},
AcceptPartnerClaimAuthority {
partner: Pubkey,
},
TransferPartnerClaimAuthority {
partner: Pubkey,
new_authority: Pubkey,
},
CreateMetadata {},
FetchTicks {
clmmpool: Pubkey,
},
}Variants
AcceptProtocolFeeAuthority
Fields
clmm_config: PubkeyThe clmm_config is the config of new_authority to accept
recalled by the new ClmmConfig authority to accept the authority
CollectPartnerFee
collect the partner fee from ata controlled by partner pda
CollectProtocolFee
Fields
clmmpool: PubkeyThe clmmpool key
protocol_fee_claim_authority to collect the fee earn by the clmmpool
CreatePool
Fields
create a clmm_pool
PausePool
Fields
clmmpool: PubkeyThe clmmpool key
pause clmm_pool
UnpausePool
Fields
clmmpool: PubkeyThe clmmpool key
unpause clmm_pool
Info
Fields
pair_key: Pubkeypool key
get clmm_pool info
List
Fields
get clmm_pool list
InitConfig
Fields
init clmm_config
ConfigInfo
Fields
get config_info
CreateFeeTier
Fields
create fee tier
FeeTierInfo
Fields
fee_tier: PubkeyThe fee_tier key
get fee_tier_info
CreatePartner
Fields
create partner
PartnerInfo
Fields
partner: PubkeyThe partner key
get partner_info
CreateTickArray
Fields
create tick array
TransferProtocolFeeAuthority
Fields
clmm_config: PubkeyThe clmm_config to transfer to new_authority
The new_authority will be the new authority of clmm_config
protocol_fee_authority of the ClmmConfig to another new authority
UpdateConfig
Fields
clmm_config: Pubkeyprotocol_fee_authority is the authority to update protocol_fee_rate
new_protocol_fee_rate: Option<u16>The new_protocol_fee_rate of config, exp: 2000, is 2000/10**4 = 20%.
create_pool_authority. default key(11111111111111111111111111111111), everyone can create pool.
protocol_fee claim authority.
update the protocol_fee_rate on ClmmConfig
UpdateFeeRate
Fields
new_fee_rate: f64The new_fee_rate to update clmmpool, exp: 0.002, 0.002 = 0.2%.
clmmpool: PubkeyThe clmmpool to update the fee_rate
update the fee_rate on the clmmpool
UpdatePartner
Fields
partner: Pubkeypartner is the existed partner to update
The new claim authority to update partner
update partner fee_rate or claim authority
Swap
swap
SwapWithPartner
swap with partner
InitRewarder
Fields
clmmpool: PubkeyThe pool key
rewarder_token_mint: PubkeyThe rewarder token mint
rewarder_index: u8The rewarder index
mint_wrapper: PubkeyThe mint wrapper
minter: PubkeyThe minter
initialize rewarder
UpdateRewarderEmission
Fields
clmmpool: PubkeyThe pool key
rewarder_index: u8The rewarder index
emissions_per_day: f64The emissions per day in tokens. Exp: 200, means 200.0, no decimal; if the rewarder token decimal is 6, the emissions will be ((200 * 10 ** 6) << 64).div(60 * 60 * 24);
update rewarder emission
AcceptPartnerClaimAuthority
Fields
partner: Pubkeyaccept partner claim authority
TransferPartnerClaimAuthority
transfer partner claim authority
CreateMetadata
Fields
crate clmmpool position metadata
FetchTicks
Fields
clmmpool: PubkeyThe clmmpool address
Fetch clmmpool ticks