pub struct Clmmpool {Show 19 fields
pub clmm_config: Pubkey,
pub token_a: Pubkey,
pub token_b: Pubkey,
pub token_a_vault: Pubkey,
pub token_b_vault: Pubkey,
pub tick_spacing: u16,
pub tick_spacing_seed: u16,
pub fee_rate: u16,
pub protocol_fee_rate: u16,
pub liquidity: u128,
pub current_sqrt_price: u128,
pub current_tick_index: i32,
pub fee_growth_global_a: u128,
pub fee_growth_global_b: u128,
pub fee_protocol_token_a: u64,
pub fee_protocol_token_b: u64,
pub bump: u8,
pub reward_infos: Rewarders,
pub reward_last_updated_time: u64,
}Fields
clmm_config: Pubkeyclmm_config
token_a: PubkeyThe pool token a mint address.
token_b: PubkeyThe pool token b mint address.
token_a_vault: PubkeyThe vault for hold clmmpool’s token a.
token_b_vault: PubkeyThe vault for hold clmmpool’s token b.
tick_spacing: u16The tick spacing.
tick_spacing_seed: u16fee_rate: u16The numerator of fee rate, the denominator is 1_000_000.
protocol_fee_rate: u16The numerator of protocol fee rate, the denominator is 1_000_0. Protocol fee amount = fee_amount * protocol_fee_rate.
liquidity: u128The liquidity of current tick index.
current_sqrt_price: u128The current sqrt price, Q64.64 and MAX/MIN is Q32.64.
current_tick_index: i32The current tick index.
fee_growth_global_a: u128The fee growth a as Q64.64.
fee_growth_global_b: u128The fee growth b as Q64.64.
fee_protocol_token_a: u64The amounts of token a owed to protocol.
fee_protocol_token_b: u64The amounts of token b owed to protocol.
bump: u8The bump
reward_infos: Rewardersreward_last_updated_time: u64Implementations
sourceimpl Clmmpool
impl Clmmpool
pub const REWARD_NUM: usize = 3usize
pub const LEN: usize = 741usize
pub fn get_info(rpc_client: &RpcClient, pubkey: &Pubkey) -> Self
pub fn get_tick_map_address(pool: &Pubkey) -> Pubkey
pub fn get_ui_info(self, clmmpool: Pubkey) -> ClmmpoolUiList