pub struct Rewarder {
pub mint_wrapper: Pubkey,
pub minter: Pubkey,
pub mint: Pubkey,
pub authority: Pubkey,
pub emissions_per_second: u128,
pub growth_global: u128,
}Fields
mint_wrapper: Pubkeyminter: Pubkeymint: PubkeyReward token mint.
Authority account that has permission to initialize the reward and set emissions.
emissions_per_second: u128Q64.64 number that indicates how many tokens per second are earned per unit of liquidity.
growth_global: u128Q64.64 number that tracks the total tokens earned per unit of liquidity since the reward emissions were turned on.
Implementations