pub struct ClmmConfig {
    pub protocol_fee_authority: Pubkey,
    pub protocol_fee_claim_authority: Pubkey,
    pub protocol_fee_rate: u16,
    pub pending_authority: Pubkey,
}

Fields

protocol_fee_authority: Pubkey

The authority of token accounts for receive protocol fee.

protocol_fee_claim_authority: Pubkey

The authority for claim protocol fee

protocol_fee_rate: u16

The protocol fee rate

pending_authority: Pubkey

pending_authority is used when transfer authority, store the new authority to accept in next step and as the new authority.