pub struct Minter {
    pub mint_wrapper: Pubkey,
    pub minter_authority: Pubkey,
    pub bump: u8,
    pub index: u64,
    pub allowance: u64,
    pub total_minted: u64,
}

Fields

mint_wrapper: Pubkey

The mint wrapper.

minter_authority: Pubkey

Address that can mint.

bump: u8

Bump seed.

index: u64

Auto-incrementing index of the Minter.

allowance: u64

Limit of number of tokens that this Minter can mint.

total_minted: u64

Cumulative sum of the number of tokens ever minted by this Minter.

Implementations