pub enum PairCommands {
Show 26 variants AcceptProtocolFeeAuthority { clmm_config: Pubkey, }, CollectPartnerFee { partner: Pubkey, clmmpool: Pubkey, }, CollectProtocolFee { clmmpool: Pubkey, }, CreatePoolTemplate { output_file: String, }, CreatePool { entry_file: String, }, Info { pair_key: Pubkey, }, List {}, ConfigInitTemplate { output_file: String, }, ConfigInit { entry_file: String, }, ConfigInfo { config_key: Pubkey, }, FeeTierCreateTemplate { output_file: String, }, FeeTierCreate { entry_file: String, }, FeeTierInfo { fee_tier: Pubkey, }, PartnerCreateTemplate { output_file: String, }, PartnerCreate { entry_file: String, }, PartnerInfo { partner: Pubkey, }, TickArrayCreateTemplate { output_file: String, }, TickArrayCreate { entry_file: String, }, TransferProtocolFeeAuthority { clmm_config: Pubkey, new_authority: Pubkey, }, ConfigProtocolFeeRateUpdate { clmm_config: Pubkey, new_protocol_fee_rate: u16, }, FeeRateUpdate { new_fee_rate: f64, clmmpool: Pubkey, }, PartnerUpdate { partner: Pubkey, new_fee_rate: Option<u16>, new_claim_authority: Option<Pubkey>, }, Swap { clmmpool: Pubkey, amount: f64, a_to_b: Option<bool>, by_amount_in: Option<bool>, price_limit_tick: Option<i32>, }, SwapWithPartner { clmmpool: Pubkey, partner: Pubkey, amount: f64, a_to_b: Option<bool>, by_amount_in: Option<bool>, price_limit_tick: Option<i32>, }, InitRewarder { clmmpool: Pubkey, rewarder_authority_file: String, rewarder_token_mint: Pubkey, rewarder_index: u8, mint_wrapper: Pubkey, minter: Pubkey, }, UpdateRewarderEmission { clmmpool: Pubkey, rewarder_authority_file: String, rewarder_index: u8, emissions_per_day: f64, },
}

Variants

AcceptProtocolFeeAuthority

Fields

clmm_config: Pubkey

The clmm_config is the config of new_authority to accept

recalled by the new ClmmConfig authority to accept the authority

CollectPartnerFee

Fields

partner: Pubkey

The partner key

clmmpool: Pubkey

The clmmpool key

collect the partner fee from ata controlled by partner pda

CollectProtocolFee

Fields

clmmpool: Pubkey

The clmmpool key

protocol_fee_claim_authority to collect the fee earn by the clmmpool

CreatePoolTemplate

Fields

output_file: String

The config file output path (default: ./clmmpool-template.yaml)

create a yaml template for the create-pool

CreatePool

Fields

entry_file: String

The config file entry path (default: ./clmmpool-template.yaml)

create a clmm_pool

Info

Fields

pair_key: Pubkey

pool key

get clmm_pool info

List

Fields

get clmm_pool list

ConfigInitTemplate

Fields

output_file: String

The config file output path (default: ./clmm-config-template.yaml)

create a yaml template for the init-config

ConfigInit

Fields

entry_file: String

The config file entry path (default: ./clmm-config-template.yaml)

init clmm_config

ConfigInfo

Fields

config_key: Pubkey

The config key

get config_info

FeeTierCreateTemplate

Fields

output_file: String

The config file output path (default: ./fee-tier-template.yaml)

create a yaml template for the create-fee-tier

FeeTierCreate

Fields

entry_file: String

The config file entry path (default: ./fee-tier-template.yaml)

create fee tier

FeeTierInfo

Fields

fee_tier: Pubkey

The fee_tier key

get fee_tier_info

PartnerCreateTemplate

Fields

output_file: String

The config file output path (default: ./partner-template.yaml)

create a yaml template for the create-partner

PartnerCreate

Fields

entry_file: String

The config file entry path (default: ./partner-template.yaml)

create partner

PartnerInfo

Fields

partner: Pubkey

The partner key

get partner_info

TickArrayCreateTemplate

Fields

output_file: String

The config file output path (default: ./tick-array-template.yaml)

create a yaml template for the create-tick-array

TickArrayCreate

Fields

entry_file: String

The config file entry path (default: ./tick-array-template.yaml)

create tick array

TransferProtocolFeeAuthority

Fields

clmm_config: Pubkey

The clmm_config to transfer to new_authority

new_authority: Pubkey

The new_authority will be the new authority of clmm_config

protocol_fee_authority of the ClmmConfig to another new authority

ConfigProtocolFeeRateUpdate

Fields

clmm_config: Pubkey

protocol_fee_authority is the authority to update protocol_fee_rate

new_protocol_fee_rate: u16

The new_protocol_fee_rate to update protocol config

update the protocol_fee_rate on ClmmConfig

FeeRateUpdate

Fields

new_fee_rate: f64

The new_fee_rate to update clmmpool

clmmpool: Pubkey

The clmmpool to update the fee_rate

update the fee_rate on the clmmpool

PartnerUpdate

Fields

partner: Pubkey

partner is the existed partner to update

new_fee_rate: Option<u16>

The new fee rate to update partner

new_claim_authority: Option<Pubkey>

The new claim authority to update partner

update partner fee_rate or claim authority

Swap

Fields

clmmpool: Pubkey

The clmmpool

amount: f64

swap amount

a_to_b: Option<bool>

swap direction, true: a->b, false: b->a

by_amount_in: Option<bool>

swap by amount in, ture: in, false: out

price_limit_tick: Option<i32>

swap price limit for tick

swap

SwapWithPartner

Fields

clmmpool: Pubkey

The clmmpool

partner: Pubkey

The partner

amount: f64

swap amount

a_to_b: Option<bool>

swap direction, true: a->b, false: b->a

by_amount_in: Option<bool>

swap by amount in, ture: in, false: out

price_limit_tick: Option<i32>

swap price limit for tick

swap with partner

InitRewarder

Fields

clmmpool: Pubkey

The pool key

rewarder_authority_file: String

The rewarder authority private file(clmm_config.protocol_authority)

rewarder_token_mint: Pubkey

The rewarder token mint

rewarder_index: u8

The rewarder index

mint_wrapper: Pubkey

The mint wrapper

minter: Pubkey

The minter

initialize rewarder

UpdateRewarderEmission

Fields

clmmpool: Pubkey

The pool key

rewarder_authority_file: String

The rewarder authority private file(clmm_config.protocol_authority)

rewarder_index: u8

The rewarder index

emissions_per_day: f64

The emissions per day

update rewarder emission