pub enum PositionCommands {
    CollectRewarder {
        mint: Pubkey,
        rewarder_index: u8,
    },
    Open {
        clmmpool: Pubkey,
        tick_lower_index: i32,
        tick_upper_index: i32,
    },
    Remove {
        mint: Pubkey,
    },
    Decrease {
        mint: Pubkey,
        amount_a: f64,
        amount_b: f64,
        liquidity: u128,
        slid: f64,
    },
    Increase {
        mint: Pubkey,
        amount_a: f64,
        amount_b: f64,
        slid: f64,
    },
    IncreaseWithFixedToken {
        mint: Pubkey,
        amount: f64,
        slid: f64,
        is_a_fixed: Option<bool>,
    },
    List {
        clmmpool: Option<Pubkey>,
        auth: Option<Pubkey>,
    },
    Info {
        mint: Pubkey,
    },
    CollectFee {
        mint: Pubkey,
    },
}

Variants

CollectRewarder

Fields

mint: Pubkey

provider the position mint address

rewarder_index: u8

rewarder index for position rewarders

collect rewarder

Open

Fields

clmmpool: Pubkey

pool key

tick_lower_index: i32

tick lower index

tick_upper_index: i32

tick upper index

open a new position

Remove

Fields

mint: Pubkey

remove a position

provider the position mint address

Decrease

Fields

mint: Pubkey

provider the position mint key

amount_a: f64

The token amount a

amount_b: f64

The token amount b

liquidity: u128

The liquidity

slid: f64

The slid rate (default 0.01)

decrease liquidity to position

Increase

Fields

mint: Pubkey

provider the position mint key

amount_a: f64

The token amount a

amount_b: f64

The token amount b

slid: f64

The slid rate (default 0.01)

increase liquidity to position

IncreaseWithFixedToken

Fields

mint: Pubkey
amount: f64
slid: f64
is_a_fixed: Option<bool>

List

Fields

clmmpool: Option<Pubkey>

The clmm pool key

auth: Option<Pubkey>

The user owner key

get position list

Info

Fields

mint: Pubkey

provider the position mint address to retreive the position details

get position info

CollectFee

Fields

mint: Pubkey

provider the position mint address

position owner to collect the fee the position owned