Enum clmm_cli::app::PositionCommands
source · [−]pub enum PositionCommands {
CollectRewarder {
mint: Pubkey,
rewarder_index: u8,
},
Open {
clmmpool: Pubkey,
tick_lower_index: i32,
tick_upper_index: i32,
},
Remove {
mint: Pubkey,
},
Decrease {
mint: Pubkey,
amount_a: f64,
amount_b: f64,
liquidity: u128,
slid: f64,
},
Increase {
mint: Pubkey,
amount_a: f64,
amount_b: f64,
slid: f64,
},
IncreaseWithFixedToken {
mint: Pubkey,
amount: f64,
slid: f64,
is_a_fixed: Option<bool>,
},
List {
clmmpool: Option<Pubkey>,
auth: Option<Pubkey>,
},
Info {
mint: Pubkey,
},
CollectFee {
mint: Pubkey,
},
}Variants
CollectRewarder
Fields
mint: Pubkeyprovider the position mint address
rewarder_index: u8rewarder index for position rewarders
collect rewarder
Open
Fields
clmmpool: Pubkeypool key
tick_lower_index: i32tick lower index
tick_upper_index: i32tick upper index
open a new position
Remove
Fields
mint: Pubkeyremove a position
provider the position mint address
Decrease
Fields
mint: Pubkeyprovider the position mint key
amount_a: f64The token amount a
amount_b: f64The token amount b
liquidity: u128The liquidity
slid: f64The slid rate (default 0.01)
decrease liquidity to position
Increase
Fields
mint: Pubkeyprovider the position mint key
amount_a: f64The token amount a
amount_b: f64The token amount b
slid: f64The slid rate (default 0.01)
increase liquidity to position
IncreaseWithFixedToken
List
get position list
Info
Fields
mint: Pubkeyprovider the position mint address to retreive the position details
get position info
CollectFee
Fields
mint: Pubkeyprovider the position mint address
position owner to collect the fee the position owned