pub struct Clmmpool {
Show 19 fields pub clmm_config: Pubkey, pub token_a: Pubkey, pub token_b: Pubkey, pub token_a_vault: Pubkey, pub token_b_vault: Pubkey, pub tick_spacing: u16, pub tick_spacing_seed: u16, pub fee_rate: u16, pub protocol_fee_rate: u16, pub liquidity: u128, pub current_sqrt_price: u128, pub current_tick_index: i32, pub fee_growth_global_a: u128, pub fee_growth_global_b: u128, pub fee_protocol_token_a: u64, pub fee_protocol_token_b: u64, pub bump: u8, pub reward_infos: Rewarders, pub reward_last_updated_time: u64,
}

Fields

clmm_config: Pubkey

clmm_config

token_a: Pubkey

The pool token a mint address.

token_b: Pubkey

The pool token b mint address.

token_a_vault: Pubkey

The vault for hold clmmpool’s token a.

token_b_vault: Pubkey

The vault for hold clmmpool’s token b.

tick_spacing: u16

The tick spacing.

tick_spacing_seed: u16fee_rate: u16

The numerator of fee rate, the denominator is 1_000_000.

protocol_fee_rate: u16

The numerator of protocol fee rate, the denominator is 1_000_0. Protocol fee amount = fee_amount * protocol_fee_rate.

liquidity: u128

The liquidity of current tick index.

current_sqrt_price: u128

The current sqrt price, Q64.64 and MAX/MIN is Q32.64.

current_tick_index: i32

The current tick index.

fee_growth_global_a: u128

The fee growth a as Q64.64.

fee_growth_global_b: u128

The fee growth b as Q64.64.

fee_protocol_token_a: u64

The amounts of token a owed to protocol.

fee_protocol_token_b: u64

The amounts of token b owed to protocol.

bump: u8

The bump

reward_infos: Rewardersreward_last_updated_time: u64

Implementations